﻿using System.Collections;
using UnityEngine;
using UnityEngine.InputSystem;

public class PlayerControl : MonoBehaviour
{
    [Header("User settings")]
    public CharacterController control;

    public float speed = 10;

    public float lookPower = 0.1f;

    public float lowerLookBound = -30;

    public float upperLookBound = 60;

    [Header("Autogenerated values")]
    public Vector3 currentMovement;

    public Vector3 currentLook;

    [Tooltip("Gravitational acceleration.")]
    public Vector3 gravity = new(0, -9.81f, 0);

    [Tooltip("Velocity of gravity.")]
    public Vector3 gravityVelocity;

    private bool mouseHeld = false;

    public void OnMove(InputAction.CallbackContext context)
    {
        Vector2 rawMove = context.ReadValue<Vector2>();
        currentMovement = new Vector3(rawMove.x, 0, rawMove.y) * speed;
    }

    public void OnLook(InputAction.CallbackContext context)
    {
        if (mouseHeld)
        {
            Vector2 rawLook = context.ReadValue<Vector2>();
            currentLook = new(
                rawLook.y * lookPower,
                rawLook.x * lookPower, 0);
        }
        else if (context.canceled)
            currentLook = Vector3.zero;
    }

    public void OnLookHold(InputAction.CallbackContext context)
    {
        mouseHeld = context.performed;
    }

    private void FixedUpdate()
    {
        if (control.isGrounded)
        {
            gravityVelocity = Vector3.zero;
        }
        else
        {
            gravityVelocity += gravity * Time.deltaTime;
        }

        transform.Rotate(currentLook);
        // Clamp up down rotation
        transform.rotation = Quaternion.Euler(
            ExtensionMethods.ClampAngle(transform.eulerAngles.x, lowerLookBound, upperLookBound),
            transform.eulerAngles.y, 0);

        control.Move(transform.rotation * (currentMovement) + gravityVelocity);
    }
}